# -*- ruby encoding: utf-8 -*-
#############################################################
# This file was automatically generated on 2019-11-25.      #
#                                                           #
# Ruby Bindings Version 2.1.24                              #
#                                                           #
# If you have a bugfix for this file and want to commit it, #
# please fix the bug in the generator. You can find a link  #
# to the generators git repository on tinkerforge.com       #
#############################################################

module Tinkerforge
  # Detects presence of magnetic field
  class BrickletHallEffect < Device
    DEVICE_IDENTIFIER = 240 # :nodoc:
    DEVICE_DISPLAY_NAME = 'Hall Effect Bricklet' # :nodoc:

    # This callback is triggered periodically with the period that is set by
    # BrickletHallEffect#set_edge_count_callback_period. The parameters are the
    # current count and the current value (see BrickletHallEffect#get_value and
    # BrickletHallEffect#get_edge_count).
    # 
    # The CALLBACK_EDGE_COUNT callback is only triggered if the count or value changed
    # since the last triggering.
    CALLBACK_EDGE_COUNT = 10

    FUNCTION_GET_VALUE = 1 # :nodoc:
    FUNCTION_GET_EDGE_COUNT = 2 # :nodoc:
    FUNCTION_SET_EDGE_COUNT_CONFIG = 3 # :nodoc:
    FUNCTION_GET_EDGE_COUNT_CONFIG = 4 # :nodoc:
    FUNCTION_SET_EDGE_INTERRUPT = 5 # :nodoc:
    FUNCTION_GET_EDGE_INTERRUPT = 6 # :nodoc:
    FUNCTION_SET_EDGE_COUNT_CALLBACK_PERIOD = 7 # :nodoc:
    FUNCTION_GET_EDGE_COUNT_CALLBACK_PERIOD = 8 # :nodoc:
    FUNCTION_EDGE_INTERRUPT = 9 # :nodoc:
    FUNCTION_GET_IDENTITY = 255 # :nodoc:

    EDGE_TYPE_RISING = 0 # :nodoc:
    EDGE_TYPE_FALLING = 1 # :nodoc:
    EDGE_TYPE_BOTH = 2 # :nodoc:

    # Creates an object with the unique device ID <tt>uid</tt> and adds it to
    # the IP Connection <tt>ipcon</tt>.
    def initialize(uid, ipcon)
      super uid, ipcon

      @api_version = [2, 0, 0]

      @response_expected[FUNCTION_GET_VALUE] = RESPONSE_EXPECTED_ALWAYS_TRUE
      @response_expected[FUNCTION_GET_EDGE_COUNT] = RESPONSE_EXPECTED_ALWAYS_TRUE
      @response_expected[FUNCTION_SET_EDGE_COUNT_CONFIG] = RESPONSE_EXPECTED_FALSE
      @response_expected[FUNCTION_GET_EDGE_COUNT_CONFIG] = RESPONSE_EXPECTED_ALWAYS_TRUE
      @response_expected[FUNCTION_SET_EDGE_INTERRUPT] = RESPONSE_EXPECTED_TRUE
      @response_expected[FUNCTION_GET_EDGE_INTERRUPT] = RESPONSE_EXPECTED_ALWAYS_TRUE
      @response_expected[FUNCTION_SET_EDGE_COUNT_CALLBACK_PERIOD] = RESPONSE_EXPECTED_TRUE
      @response_expected[FUNCTION_GET_EDGE_COUNT_CALLBACK_PERIOD] = RESPONSE_EXPECTED_ALWAYS_TRUE
      @response_expected[FUNCTION_EDGE_INTERRUPT] = RESPONSE_EXPECTED_ALWAYS_TRUE
      @response_expected[FUNCTION_GET_IDENTITY] = RESPONSE_EXPECTED_ALWAYS_TRUE

      @callback_formats[CALLBACK_EDGE_COUNT] = 'L ?'

    end

    # Returns *true* if a magnetic field of 35 Gauss (3.5mT) or greater is detected.
    def get_value
      send_request FUNCTION_GET_VALUE, [], '', 1, '?'
    end

    # Returns the current value of the edge counter. You can configure
    # edge type (rising, falling, both) that is counted with
    # BrickletHallEffect#set_edge_count_config.
    # 
    # If you set the reset counter to *true*, the count is set back to 0
    # directly after it is read.
    def get_edge_count(reset_counter)
      send_request FUNCTION_GET_EDGE_COUNT, [reset_counter], '?', 4, 'L'
    end

    # The edge type parameter configures if rising edges, falling edges or
    # both are counted. Possible edge types are:
    # 
    # * 0 = rising (default)
    # * 1 = falling
    # * 2 = both
    # 
    # A magnetic field of 35 Gauss (3.5mT) or greater causes a falling edge and a
    # magnetic field of 25 Gauss (2.5mT) or smaller causes a rising edge.
    # 
    # If a magnet comes near the Bricklet the signal goes low (falling edge), if
    # a magnet is removed from the vicinity the signal goes high (rising edge).
    # 
    # The debounce time is given in ms.
    # 
    # Configuring an edge counter resets its value to 0.
    # 
    # If you don't know what any of this means, just leave it at default. The
    # default configuration is very likely OK for you.
    def set_edge_count_config(edge_type, debounce)
      send_request FUNCTION_SET_EDGE_COUNT_CONFIG, [edge_type, debounce], 'C C', 0, ''
    end

    # Returns the edge type and debounce time as set by BrickletHallEffect#set_edge_count_config.
    def get_edge_count_config
      send_request FUNCTION_GET_EDGE_COUNT_CONFIG, [], '', 2, 'C C'
    end

    # Sets the number of edges until an interrupt is invoked.
    # 
    # If *edges* is set to n, an interrupt is invoked for every n-th detected edge.
    # 
    # If *edges* is set to 0, the interrupt is disabled.
    # 
    # Default value is 0.
    def set_edge_interrupt(edges)
      send_request FUNCTION_SET_EDGE_INTERRUPT, [edges], 'L', 0, ''
    end

    # Returns the edges as set by BrickletHallEffect#set_edge_interrupt.
    def get_edge_interrupt
      send_request FUNCTION_GET_EDGE_INTERRUPT, [], '', 4, 'L'
    end

    # Sets the period with which the CALLBACK_EDGE_COUNT callback is triggered
    # periodically. A value of 0 turns the callback off.
    # 
    # The CALLBACK_EDGE_COUNT callback is only triggered if the edge count has changed
    # since the last triggering.
    def set_edge_count_callback_period(period)
      send_request FUNCTION_SET_EDGE_COUNT_CALLBACK_PERIOD, [period], 'L', 0, ''
    end

    # Returns the period as set by BrickletHallEffect#set_edge_count_callback_period.
    def get_edge_count_callback_period
      send_request FUNCTION_GET_EDGE_COUNT_CALLBACK_PERIOD, [], '', 4, 'L'
    end

    # This callback is triggered every n-th count, as configured with
    # BrickletHallEffect#set_edge_interrupt. The parameters are the
    # current count and the current value (see BrickletHallEffect#get_value and
    # BrickletHallEffect#get_edge_count).
    def edge_interrupt
      send_request FUNCTION_EDGE_INTERRUPT, [], '', 5, 'L ?'
    end

    # Returns the UID, the UID where the Bricklet is connected to,
    # the position, the hardware and firmware version as well as the
    # device identifier.
    # 
    # The position can be 'a', 'b', 'c' or 'd'.
    # 
    # The device identifier numbers can be found :ref:`here <device_identifier>`.
    # |device_identifier_constant|
    def get_identity
      send_request FUNCTION_GET_IDENTITY, [], '', 25, 'Z8 Z8 k C3 C3 S'
    end

    # Registers a callback with ID <tt>id</tt> to the block <tt>block</tt>.
    def register_callback(id, &block)
      callback = block
      @registered_callbacks[id] = callback
    end
  end
end
